
/* Chrysalide - Outil d'analyse de fichiers binaires
 * project.c - équivalent Python du fichier "analysis/project.c"
 *
 * Copyright (C) 2018 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  Chrysalide is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Chrysalide is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


#include "project.h"


#include <assert.h>
#include <pygobject.h>


#include <analysis/project.h>


#include "../helpers.h"



/* Procède à l'enregistrement d'un projet donné. */
static PyObject *py_study_project_save(PyObject *, PyObject *);



/******************************************************************************
*                                                                             *
*  Paramètres  : self = contenu binaire à manipuler.                          *
*                args = arguments accompagnant l'appel.                       *
*                                                                             *
*  Description : Procède à l'enregistrement d'un projet donné.                *
*                                                                             *
*  Retour      : Py_True si l'enregistrement s'est déroule sans encombre.     *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

static PyObject *py_study_project_save(PyObject *self, PyObject *args)
{
    PyObject *result;                       /* Instance à retourner        */
    GStudyProject *project;                 /* Version GLib du format      */
    const char *filename;                   /* Destination de la sauvegarde*/
    int ret;                                /* Bilan de lecture des args.  */
    bool status;                            /* Bilan de l'opération        */

    project = G_STUDY_PROJECT(pygobject_get(self));
    assert(project != NULL);

    ret = PyArg_ParseTuple(args, "s", &filename);
    if (!ret) return NULL;

    status = g_study_project_save(project, filename);

    result = status ? Py_True : Py_False;
    Py_INCREF(result);

    return result;

}


/******************************************************************************
*                                                                             *
*  Paramètres  : -                                                            *
*                                                                             *
*  Description : Fournit un accès à une définition de type à diffuser.        *
*                                                                             *
*  Retour      : Définition d'objet pour Python.                              *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

PyTypeObject *get_python_study_project_type(void)
{
    static PyMethodDef py_study_project_methods[] = {
        {
            "save", py_study_project_save,
            METH_VARARGS,
            "save($self, filename, /)\n--\n\nSave the project into a given file."
        },
        { NULL }
    };

    static PyGetSetDef py_study_project_getseters[] = {
        { NULL }
    };

    static PyTypeObject py_study_project_type = {

        PyVarObject_HEAD_INIT(NULL, 0)

        .tp_name        = "pychrysalide.analysis.StudyProject",

        .tp_flags       = Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE,

        .tp_doc         = "PyChrysalide study project",

        .tp_methods     = py_study_project_methods,
        .tp_getset      = py_study_project_getseters

    };

    return &py_study_project_type;

}


/******************************************************************************
*                                                                             *
*  Paramètres  : module = module dont la définition est à compléter.          *
*                                                                             *
*  Description : Prend en charge l'objet 'pychrysalide.analysis.StudyProject'.*
*                                                                             *
*  Retour      : Bilan de l'opération.                                        *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

bool register_python_study_project(PyObject *module)
{
    PyTypeObject *py_study_project_type;    /* Type Python 'StudyProject'  */
    PyObject *dict;                         /* Dictionnaire du module      */

    py_study_project_type = get_python_study_project_type();

    dict = PyModule_GetDict(module);

    if (!register_class_for_pygobject(dict, G_TYPE_STUDY_PROJECT, py_study_project_type, &PyGObject_Type))
        return false;

    return true;

}
